==> otb_6.4.0+dfsg.orig.tar.xz: OTB-release-6.4/Modules/Wrappers/ApplicationEngine/include/otbWrapperNumericalParameter.h <==
/*
 * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
 *
 * This file is part of Orfeo Toolbox
 *
 *     https://www.orfeo-toolbox.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef otbWrapperNumericalParameter_h
#define otbWrapperNumericalParameter_h

#include "otbWrapperParameter.h"
#include "itkNumericTraits.h"
#include <boost/any.hpp>

namespace otb
{
namespace Wrapper
{
/** \class NumericalParameter
 *  \brief This class represents a numerical parameter
 *
 * \ingroup OTBApplicationEngine
 */
template <class T>
class ITK_ABI_EXPORT NumericalParameter : public Parameter
{
public:
  /** Standard class typedef */
  typedef NumericalParameter            Self;
  typedef Parameter                     Superclass;
  typedef itk::SmartPointer<Self>       Pointer;
  typedef itk::SmartPointer<const Self> ConstPointer;

  /** Defining ::New() static method */
  itkNewMacro(Self);

  /** RTTI support */
  itkTypeMacro(NumericalParameter, Parameter);

  /** Typedef of the scalar type */
  typedef T ScalarType;

  /** Implement the reset method (replace value by default value) */
  void Reset() ITK_OVERRIDE
  {
    m_Value = m_DefaultValue;
  }

  /** Set the value */
  void SetValue( ScalarType value)
  {
    // TODO check minimum/maximum
    m_Value = value;

    // Set Active only if the parameter is not automatically set
    if (!GetAutomaticValue())
      {
      SetActive(true);
      }
  }

  void SetValue( const std::string & valueStr )
  {
    ScalarType value = static_cast<ScalarType>(atof(valueStr.c_str()));
    SetValue(value);
  }

  /** Get the value */
  ScalarType GetValue() const
  {
    if (!HasValue())
      {
      itkGenericExceptionMacro(<< "Parameter " << this->GetKey() << " has no value yet.");
      }
    return boost::any_cast<ScalarType>(m_Value);
  }

  bool HasValue() const ITK_OVERRIDE
  {
    return !m_Value.empty();
  }

  void ClearValue() ITK_OVERRIDE
  {
    m_Value = boost::any();
  }

  /** Set the default value */
  itkSetMacro(DefaultValue, ScalarType);

  /** Get the default value */
  itkGetMacro(DefaultValue, ScalarType);

  /** Set the minimum value */
  itkSetMacro(MinimumValue, ScalarType);

  /** Get the minimum value */
  itkGetMacro(MinimumValue, ScalarType);

  /** Set the maximum value */
  itkSetMacro(MaximumValue, ScalarType);

  /** Get the maximum value */
  itkGetMacro(MaximumValue, ScalarType);

protected:
  /** Constructor */
  NumericalParameter()
    : m_DefaultValue(itk::NumericTraits<T>::Zero),
      m_MinimumValue(itk::NumericTraits<T>::NonpositiveMin()),
      m_MaximumValue(itk::NumericTraits<T>::max())
  {}

  /** Destructor */
  ~NumericalParameter() ITK_OVERRIDE
  {}

  /** Value */
  boost::any m_Value;

  /** Default value (when appliable) */
  ScalarType m_DefaultValue;

  /** Minimum value */
  ScalarType m_MinimumValue;

  /** Maximum value */
  ScalarType m_MaximumValue;

private:
  NumericalParameter(const Parameter &); //purposely not implemented
  void operator =(const Parameter&); //purposely not implemented

}; // End class Numerical Parameter

// Helper typedef for float
typedef NumericalParameter<float> FloatParameter;

// Helper typedef for int
typedef NumericalParameter<int> IntParameter;

} // End namespace Wrapper
} // End namespace otb

#endif

==> otb_6.6.0+dfsg.orig.tar.xz: OTB-release-6.6/Modules/Wrappers/ApplicationEngine/include/otbWrapperNumericalParameter.h <==
/*
 * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
 *
 * This file is part of Orfeo Toolbox
 *
 *     https://www.orfeo-toolbox.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef otbWrapperNumericalParameter_h
#define otbWrapperNumericalParameter_h

#include "otbWrapperParameter.h"
#include "itkNumericTraits.h"
#include <boost/any.hpp>

namespace otb
{
namespace Wrapper
{
/** \class NumericalParameter
 *  \brief This class represents a numerical parameter
 *
 * \ingroup OTBApplicationEngine
 */
template <class T>
class ITK_ABI_EXPORT NumericalParameter : public Parameter
{
public:
  /** Standard class typedef */
  typedef NumericalParameter            Self;
  typedef Parameter                     Superclass;
  typedef itk::SmartPointer<Self>       Pointer;
  typedef itk::SmartPointer<const Self> ConstPointer;

  /** Defining ::New() static method */
  itkNewMacro(Self);

  /** RTTI support */
  itkTypeMacro(NumericalParameter, Parameter);

  /** Typedef of the scalar type */
  typedef T ScalarType;

  /** Implement the reset method (replace value by default value) */
  void Reset() override
  {
    m_Value = m_DefaultValue;
  }

  /** Set the value */
  void SetValue( ScalarType value)
  {
    m_Value = ( value < m_MinimumValue ) ? m_MinimumValue :
              ( value < m_MaximumValue ) ? value : m_MaximumValue ;

    // Set Active only if the parameter is not automatically set
    if (!GetAutomaticValue())
      {
      SetActive(true);
      }
  }

  void SetValue( const std::string & valueStr )
  {
    ScalarType value = static_cast<ScalarType>(atof(valueStr.c_str()));
    SetValue(value);
  }

  /** Get the value */
  ScalarType GetValue() const
  {
    if (!HasValue())
      {
      itkGenericExceptionMacro(<< "Parameter " << this->GetKey() << " has no value yet.");
      }
    return boost::any_cast<ScalarType>(m_Value);
  }

  bool HasValue() const override
  {
    return !m_Value.empty();
  }

  void ClearValue() override
  {
    m_Value = boost::any();
  }

  /** Set the default value */
  itkSetMacro(DefaultValue, ScalarType);

  /** Get the default value */
  itkGetMacro(DefaultValue, ScalarType);

  /** Set the minimum value */
  itkSetMacro(MinimumValue, ScalarType);

  /** Get the minimum value */
  itkGetMacro(MinimumValue, ScalarType);

  /** Set the maximum value */
  itkSetMacro(MaximumValue, ScalarType);

  /** Get the maximum value */
  itkGetMacro(MaximumValue, ScalarType);

protected:
  /** Constructor */
  NumericalParameter()
    : m_DefaultValue(itk::NumericTraits<T>::Zero),
      m_MinimumValue(itk::NumericTraits<T>::NonpositiveMin()),
      m_MaximumValue(itk::NumericTraits<T>::max())
  {}

  /** Destructor */
  ~NumericalParameter() override
  {}

  /** Value */
  boost::any m_Value;

  /** Default value (when appliable) */
  ScalarType m_DefaultValue;

  /** Minimum value */
  ScalarType m_MinimumValue;

  /** Maximum value */
  ScalarType m_MaximumValue;

private:
  NumericalParameter(const Parameter &); //purposely not implemented
  void operator =(const Parameter&); //purposely not implemented

}; // End class Numerical Parameter

// Helper typedef for float
typedef NumericalParameter<float> FloatParameter;

// Helper typedef for int
typedef NumericalParameter<int> IntParameter;

} // End namespace Wrapper
} // End namespace otb

#endif
